[xiph-commits] r7894 - in branches/theora-mmx: . doc examples
include/theora lib win32 win32/experimental/dumpvid
win32/experimental/encoderwin win32/experimental/splayer
win32/experimental/transcoder
j at motherfish-iii.xiph.org
j at motherfish-iii.xiph.org
Thu Sep 30 04:03:25 PDT 2004
Author: j
Date: 2004-09-30 04:03:25 -0700 (Thu, 30 Sep 2004)
New Revision: 7894
Added:
branches/theora-mmx/CHANGES
branches/theora-mmx/libtheora.spec.in
branches/theora-mmx/theora-uninstalled.pc.in
Removed:
branches/theora-mmx/lib/mcomp.h
Modified:
branches/theora-mmx/
branches/theora-mmx/Makefile.am
branches/theora-mmx/configure.ac
branches/theora-mmx/doc/Doxyfile.in
branches/theora-mmx/examples/Makefile.am
branches/theora-mmx/examples/dump_video.c
branches/theora-mmx/include/theora/theora.h
branches/theora-mmx/lib/Makefile.am
branches/theora-mmx/lib/mcomp.c
branches/theora-mmx/lib/toplevel.c
branches/theora-mmx/win32/experimental/dumpvid/dumpvid.dsp
branches/theora-mmx/win32/experimental/encoderwin/encoderwin.dsp
branches/theora-mmx/win32/experimental/splayer/splayer.dsp
branches/theora-mmx/win32/experimental/transcoder/transcoder.dsp
branches/theora-mmx/win32/theora_static.dsp
Log:
Merge changes from trunk to 'theora-mmx'
Property changes on: branches/theora-mmx
___________________________________________________________________
Name: branch-point
- 7634
+ 7893
Copied: branches/theora-mmx/CHANGES (from rev 7893, trunk/theora/CHANGES)
Modified: branches/theora-mmx/Makefile.am
===================================================================
--- branches/theora-mmx/Makefile.am 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/Makefile.am 2004-09-30 11:03:25 UTC (rev 7894)
@@ -4,7 +4,8 @@
SUBDIRS = lib include doc examples debian
-EXTRA_DIST = COPYING autogen.sh win32
+EXTRA_DIST = COPYING autogen.sh win32 libtheora.spec libtheora.spec.in \
+ theora-uninstalled.pc.in
pkgconfigdir = $(libdir)/pkgconfig
pkgconfig_DATA = theora.pc
Modified: branches/theora-mmx/configure.ac
===================================================================
--- branches/theora-mmx/configure.ac 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/configure.ac 2004-09-30 11:03:25 UTC (rev 7894)
@@ -123,17 +123,59 @@
AC_CHECK_FUNC(getopt_long, [GETOPT_OBJS=''], [GETOPT_OBJS='getopt.$(OBJEXT) getopt1.$(OBJEXT)'])
AC_SUBST(GETOPT_OBJS)
-XIPH_PATH_OGG(, AC_MSG_ERROR([
+
+dnl check for Ogg
+HAVE_OGG=no
+
+dnl first check through pkg-config since it's more flexible
+
+dnl check for pkg-config itself so we don't try the m4 macro without pkg-config
+AC_CHECK_PROG(HAVE_PKG_CONFIG, pkg-config, yes)
+if test "x$HAVE_PKG_CONFIG" = "xyes"
+then
+ PKG_CHECK_MODULES(OGG, ogg >= 1.1, HAVE_OGG=yes, HAVE_OGG=no)
+fi
+if test "x$HAVE_OGG" = "xno"
+then
+ dnl fall back to the old school test
+ XIPH_PATH_OGG(, AC_MSG_ERROR([
libogg is required to build this package!
please see http://www.xiph.org/ for how to
obtain a copy.
-]))
-CFLAGS="$CFLAGS $OGG_CFLAGS"
-LIBS="$LIBS $OGG_LIBS"
-AC_CHECK_FUNC(oggpackB_read, , [
- AC_MSG_ERROR([newer libogg version (>1.0) required])
-])
+ ]))
+ cflags_save=$CFLAGS
+ libs_save=$LIBS
+ CFLAGS="$CFLAGS $OGG_CFLAGS"
+ LIBS="$LIBS $OGG_LIBS"
+ AC_CHECK_FUNC(oggpackB_read, , [
+ AC_MSG_ERROR([newer libogg version (>1.0) required])
+ ])
+ CFLAGS=$cflags_save
+ LIBS=$libs_save
+fi
+dnl the examples use Vorbis and SDL
+dnl check for Vorbis
+HAVE_VORBIS=no
+
+dnl first check through pkg-config since it's more flexible
+
+if test "x$HAVE_PKG_CONFIG" = "xyes"
+then
+ PKG_CHECK_MODULES(VORBIS, vorbis >= 1.0.1, HAVE_VORBIS=yes, HAVE_VORBIS=no)
+ dnl also set VORBISENC_LIBS since an examples needs it
+ dnl the old .m4 sets this to a value to use on top of VORBIS_LIBS,
+ dnl so we do the same here.
+ VORBISENC_LIBS="-lvorbisenc"
+ AC_SUBST(VORBISENC_LIBS)
+fi
+if test "x$HAVE_VORBIS" = "xno"
+then
+ dnl fall back to the old school test
+ XIPH_PATH_VORBIS(HAVE_VORBIS=yes, HAVE_VORBIS=no)
+fi
+
+
AM_PATH_SDL(,[
HAVE_SDL=yes
SDL_LIBS=`$SDL_CONFIG --libs`
@@ -153,9 +195,6 @@
dnl Do substitutions
dnl --------------------------------------------------
-LIBS="$LIBS"
-
-AC_SUBST(LIBS)
AC_SUBST(DEBUG)
AC_SUBST(PROFILE)
@@ -165,5 +204,7 @@
examples/Makefile
doc/Makefile doc/Doxyfile doc/python/Makefile
debian/Makefile
+ libtheora.spec
theora.pc
+ theora-uninstalled.pc
])
Modified: branches/theora-mmx/doc/Doxyfile.in
===================================================================
--- branches/theora-mmx/doc/Doxyfile.in 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/doc/Doxyfile.in 2004-09-30 11:03:25 UTC (rev 7894)
@@ -136,7 +136,7 @@
# comments will behave just like the Qt-style comments (thus requiring an
# explicit @brief command for a brief description.
-JAVADOC_AUTOBRIEF = NO
+JAVADOC_AUTOBRIEF = YES
# The MULTILINE_CPP_IS_BRIEF tag can be set to YES to make Doxygen
# treat a multi-line C++ special comment block (i.e. a block of //! or ///
Modified: branches/theora-mmx/examples/Makefile.am
===================================================================
--- branches/theora-mmx/examples/Makefile.am 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/examples/Makefile.am 2004-09-30 11:03:25 UTC (rev 7894)
@@ -7,18 +7,18 @@
# possible contents of BUILDABLE_EXAMPLES:
EXTRA_PROGRAMS = player_example encoder_example
-CFLAGS = $(SDL_CFLAGS)
-LDADD = ../lib/libtheora.la -logg
+AM_CFLAGS = $(SDL_CFLAGS) $(OGG_CFLAGS)
+LDADD = ../lib/libtheora.la $(OGG_LIBS)
dump_video_SOURCES = dump_video.c
dump_video_LDADD = $(LDADD)
player_example_SOURCES = player_example.c
-player_example_LDADD = $(LDADD) $(SDL_LIBS) -lvorbis -lm
+player_example_LDADD = $(LDADD) $(SDL_LIBS) $(VORBIS_LIBS)
encoder_example_SOURCES = encoder_example.c
EXTRA_encoder_example_SOURCES = getopt.c getopt1.c getopt.h
-encoder_example_LDADD = $(GETOPT_OBJS) $(LDADD) -lvorbisenc -lvorbis -lm
+encoder_example_LDADD = $(GETOPT_OBJS) $(LDADD) $(VORBIS_LIBS) $(VORBISENC_LIBS)
encoder_example_DEPENDENCIES = $(GETOPT_OBJS)
debug:
Modified: branches/theora-mmx/examples/dump_video.c
===================================================================
--- branches/theora-mmx/lib/Makefile.am 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/lib/Makefile.am 2004-09-30 11:03:25 UTC (rev 7894)
@@ -40,7 +40,6 @@
encoder_lookup.h \
huffman.h \
hufftables.h \
- mcomp.h \
pp.h \
quant_lookup.h \
toplevel.h \
@@ -48,7 +47,9 @@
cpu.h \
dsp.h
+libtheora_la_CFLAGS = $(OGG_CFLAGS)
libtheora_la_LDFLAGS = -version-info @V_LIB_CURRENT@:@V_LIB_REVISION@:@V_LIB_AGE@
+libtheora_la_LIBS = $(OGG_LIBS)
debug:
$(MAKE) all CFLAGS="@DEBUG@" LDFLAGS="-lefence"
Modified: branches/theora-mmx/lib/mcomp.c
===================================================================
--- branches/theora-mmx/lib/mcomp.c 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/lib/mcomp.c 2004-09-30 11:03:25 UTC (rev 7894)
@@ -729,9 +729,9 @@
dsp_static_save_fpu ();
- /* For the moment the 4MV mode is only deemd to be valid if all four
- Y blocks are to be updated */
- /* This May be adapted later. */
+ /* For the moment the 4MV mode is only deemed to be valid
+ if all four Y blocks are to be updated */
+ /* This may be adapted later. */
if ( cpi->pb.display_fragments[FragIndex] &&
cpi->pb.display_fragments[FragIndex + 1] &&
cpi->pb.display_fragments[FragIndex + cpi->pb.HFragments] &&
Property changes on: branches/theora-mmx/lib/mcomp.c
___________________________________________________________________
Name: svn:executable
- *
Deleted: branches/theora-mmx/lib/mcomp.h
===================================================================
--- branches/theora-mmx/lib/mcomp.h 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/lib/mcomp.h 2004-09-30 11:03:25 UTC (rev 7894)
@@ -1,84 +0,0 @@
-/********************************************************************
- * *
- * THIS FILE IS PART OF THE OggTheora SOFTWARE CODEC SOURCE CODE. *
- * USE, DISTRIBUTION AND REPRODUCTION OF THIS LIBRARY SOURCE IS *
- * GOVERNED BY A BSD-STYLE SOURCE LICENSE INCLUDED WITH THIS SOURCE *
- * IN 'COPYING'. PLEASE READ THESE TERMS BEFORE DISTRIBUTING. *
- * *
- * THE Theora SOURCE CODE IS COPYRIGHT (C) 2002-2003 *
- * by the Xiph.Org Foundation http://www.xiph.org/ *
- * *
- ********************************************************************
-
- function: simple static lookups for VP3 codec
- last mod: $Id: mcomp.h,v 1.4 2003/12/03 08:59:43 arc Exp $
-
- ********************************************************************/
-
-#include "encoder_internal.h"
-
-ogg_int32_t XX_LUT[511]={
- 65025, 64516, 64009, 63504, 63001, 62500, 62001, 61504,
- 61009, 60516, 60025, 59536, 59049, 58564, 58081, 57600,
- 57121, 56644, 56169, 55696, 55225, 54756, 54289, 53824,
- 53361, 52900, 52441, 51984, 51529, 51076, 50625, 50176,
- 49729, 49284, 48841, 48400, 47961, 47524, 47089, 46656,
- 46225, 45796, 45369, 44944, 44521, 44100, 43681, 43264,
- 42849, 42436, 42025, 41616, 41209, 40804, 40401, 40000,
- 39601, 39204, 38809, 38416, 38025, 37636, 37249, 36864,
- 36481, 36100, 35721, 35344, 34969, 34596, 34225, 33856,
- 33489, 33124, 32761, 32400, 32041, 31684, 31329, 30976,
- 30625, 30276, 29929, 29584, 29241, 28900, 28561, 28224,
- 27889, 27556, 27225, 26896, 26569, 26244, 25921, 25600,
- 25281, 24964, 24649, 24336, 24025, 23716, 23409, 23104,
- 22801, 22500, 22201, 21904, 21609, 21316, 21025, 20736,
- 20449, 20164, 19881, 19600, 19321, 19044, 18769, 18496,
- 18225, 17956, 17689, 17424, 17161, 16900, 16641, 16384,
- 16129, 15876, 15625, 15376, 15129, 14884, 14641, 14400,
- 14161, 13924, 13689, 13456, 13225, 12996, 12769, 12544,
- 12321, 12100, 11881, 11664, 11449, 11236, 11025, 10816,
- 10609, 10404, 10201, 10000, 9801, 9604, 9409, 9216,
- 9025, 8836, 8649, 8464, 8281, 8100, 7921, 7744,
- 7569, 7396, 7225, 7056, 6889, 6724, 6561, 6400,
- 6241, 6084, 5929, 5776, 5625, 5476, 5329, 5184,
- 5041, 4900, 4761, 4624, 4489, 4356, 4225, 4096,
- 3969, 3844, 3721, 3600, 3481, 3364, 3249, 3136,
- 3025, 2916, 2809, 2704, 2601, 2500, 2401, 2304,
- 2209, 2116, 2025, 1936, 1849, 1764, 1681, 1600,
- 1521, 1444, 1369, 1296, 1225, 1156, 1089, 1024,
- 961, 900, 841, 784, 729, 676, 625, 576,
- 529, 484, 441, 400, 361, 324, 289, 256,
- 225, 196, 169, 144, 121, 100, 81, 64,
- 49, 36, 25, 16, 9, 4, 1, 0,
- 1, 4, 9, 16, 25, 36, 49, 64,
- 81, 100, 121, 144, 169, 196, 225, 256,
- 289, 324, 361, 400, 441, 484, 529, 576,
- 625, 676, 729, 784, 841, 900, 961, 1024,
- 1089, 1156, 1225, 1296, 1369, 1444, 1521, 1600,
- 1681, 1764, 1849, 1936, 2025, 2116, 2209, 2304,
- 2401, 2500, 2601, 2704, 2809, 2916, 3025, 3136,
- 3249, 3364, 3481, 3600, 3721, 3844, 3969, 4096,
- 4225, 4356, 4489, 4624, 4761, 4900, 5041, 5184,
- 5329, 5476, 5625, 5776, 5929, 6084, 6241, 6400,
- 6561, 6724, 6889, 7056, 7225, 7396, 7569, 7744,
- 7921, 8100, 8281, 8464, 8649, 8836, 9025, 9216,
- 9409, 9604, 9801, 10000, 10201, 10404, 10609, 10816,
- 11025, 11236, 11449, 11664, 11881, 12100, 12321, 12544,
- 12769, 12996, 13225, 13456, 13689, 13924, 14161, 14400,
- 14641, 14884, 15129, 15376, 15625, 15876, 16129, 16384,
- 16641, 16900, 17161, 17424, 17689, 17956, 18225, 18496,
- 18769, 19044, 19321, 19600, 19881, 20164, 20449, 20736,
- 21025, 21316, 21609, 21904, 22201, 22500, 22801, 23104,
- 23409, 23716, 24025, 24336, 24649, 24964, 25281, 25600,
- 25921, 26244, 26569, 26896, 27225, 27556, 27889, 28224,
- 28561, 28900, 29241, 29584, 29929, 30276, 30625, 30976,
- 31329, 31684, 32041, 32400, 32761, 33124, 33489, 33856,
- 34225, 34596, 34969, 35344, 35721, 36100, 36481, 36864,
- 37249, 37636, 38025, 38416, 38809, 39204, 39601, 40000,
- 40401, 40804, 41209, 41616, 42025, 42436, 42849, 43264,
- 43681, 44100, 44521, 44944, 45369, 45796, 46225, 46656,
- 47089, 47524, 47961, 48400, 48841, 49284, 49729, 50176,
- 50625, 51076, 51529, 51984, 52441, 52900, 53361, 53824,
- 54289, 54756, 55225, 55696, 56169, 56644, 57121, 57600,
- 58081, 58564, 59049, 59536, 60025, 60516, 61009, 61504,
- 62001, 62500, 63001, 63504, 64009, 64516, 65025};
Modified: branches/theora-mmx/lib/toplevel.c
===================================================================
--- branches/theora-mmx/lib/toplevel.c 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/lib/toplevel.c 2004-09-30 11:03:25 UTC (rev 7894)
@@ -421,6 +421,19 @@
return(-1);
}
+/* check for header flag */
+int theora_packet_isheader(ogg_packet *op)
+{
+ return (op->packet[0] & 0x80) ? 1 : 0;
+}
+
+/* check for keyframe */
+int theora_packet_iskeyframe(ogg_packet *op)
+{
+ if (op->packet[0] & 0x80) return -1; /* not a data packet */
+ return (op->packet[0] & 0x40) ? 0 : 1; /* inter or intra */
+}
+
/* returns frame number of current packet in given logical stream */
ogg_int64_t theora_granule_frame(theora_state *th,ogg_int64_t granulepos){
CP_INSTANCE *cpi=(CP_INSTANCE *)(th->internal_encode);
Copied: branches/theora-mmx/libtheora.spec.in (from rev 7893, trunk/theora/libtheora.spec.in)
Copied: branches/theora-mmx/theora-uninstalled.pc.in (from rev 7893, trunk/theora/theora-uninstalled.pc.in)
Modified: branches/theora-mmx/win32/experimental/dumpvid/dumpvid.dsp
===================================================================
--- branches/theora-mmx/win32/experimental/dumpvid/dumpvid.dsp 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/win32/experimental/dumpvid/dumpvid.dsp 2004-09-30 11:03:25 UTC (rev 7894)
@@ -1,121 +1,121 @@
-# Microsoft Developer Studio Project File - Name="dumpvid" - Package Owner=<4>
-# Microsoft Developer Studio Generated Build File, Format Version 6.00
-# ** DO NOT EDIT **
-
-# TARGTYPE "Win32 (x86) Console Application" 0x0103
-
-CFG=dumpvid - Win32 Debug
-!MESSAGE This is not a valid makefile. To build this project using NMAKE,
-!MESSAGE use the Export Makefile command and run
-!MESSAGE
-!MESSAGE NMAKE /f "dumpvid.mak".
-!MESSAGE
-!MESSAGE You can specify a configuration when running NMAKE
-!MESSAGE by defining the macro CFG on the command line. For example:
-!MESSAGE
-!MESSAGE NMAKE /f "dumpvid.mak" CFG="dumpvid - Win32 Debug"
-!MESSAGE
-!MESSAGE Possible choices for configuration are:
-!MESSAGE
-!MESSAGE "dumpvid - Win32 Release" (based on "Win32 (x86) Console Application")
-!MESSAGE "dumpvid - Win32 Debug" (based on "Win32 (x86) Console Application")
-!MESSAGE
-
-# Begin Project
-# PROP AllowPerConfigDependencies 0
-# PROP Scc_ProjName ""
-# PROP Scc_LocalPath ""
-CPP=cl.exe
-RSC=rc.exe
-
-!IF "$(CFG)" == "dumpvid - Win32 Release"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 0
-# PROP BASE Output_Dir "Release"
-# PROP BASE Intermediate_Dir "Release"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 0
-# PROP Use_Debug_Libraries 0
-# PROP Output_Dir "Release"
-# PROP Intermediate_Dir "Release"
-# PROP Ignore_Export_Lib 0
-# PROP Target_Dir ""
-# ADD BASE CPP /nologo /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /c
-# ADD CPP /nologo /MD /W3 /GX /O2 /I "..\..\..\include" /I "..\..\..\..\ogg\include" /I "..\wincompat" /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /FD /c
-# SUBTRACT CPP /YX /Yc /Yu
-# ADD BASE RSC /l 0x409 /d "NDEBUG"
-# ADD RSC /l 0x409 /d "NDEBUG"
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LINK32=link.exe
-# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /machine:I386
-# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib theora_static.lib ogg_static.lib /nologo /subsystem:console /machine:I386 /nodefaultlib:"LIBCMT" /out:"dump_vid.exe" /libpath:"..\..\Static_Release" /libpath:"..\..\..\..\ogg\win32\Static_Release" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Release" /libpath:"..\..\..\..\vorbis\win32\VorbisEnc_Static_Release"
-
-!ELSEIF "$(CFG)" == "dumpvid - Win32 Debug"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "Debug"
-# PROP BASE Intermediate_Dir "Debug"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 0
-# PROP Use_Debug_Libraries 1
-# PROP Output_Dir "Debug"
-# PROP Intermediate_Dir "Debug"
-# PROP Ignore_Export_Lib 0
-# PROP Target_Dir ""
-# ADD BASE CPP /nologo /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /GZ /c
-# ADD CPP /nologo /MDd /W3 /Gm /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\..\ogg\include" /I "..\wincompat" /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /FR /FD /GZ /c
-# SUBTRACT CPP /YX /Yc /Yu
-# ADD BASE RSC /l 0x409 /d "_DEBUG"
-# ADD RSC /l 0x409 /d "_DEBUG"
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LINK32=link.exe
-# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /debug /machine:I386 /pdbtype:sept
-# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib theora_static_d.lib ogg_static_d.lib /nologo /subsystem:console /debug /machine:I386 /nodefaultlib:"LIBCD" /out:"dump_vid.exe" /pdbtype:sept /libpath:"..\..\Static_Debug" /libpath:"..\..\..\..\ogg\win32\Static_Debug" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Debug" /libpath:"..\..\..\..\vorbis\win32\VorbisEnc_Static_Debug"
-# SUBTRACT LINK32 /nodefaultlib
-
-!ENDIF
-
-# Begin Target
-
-# Name "dumpvid - Win32 Release"
-# Name "dumpvid - Win32 Debug"
-# Begin Group "Source Files"
-
-# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
-# Begin Source File
-
-SOURCE=..\..\..\examples\dump_video.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\wincompat\getopt.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\wincompat\getopt_long.c
-# End Source File
-# End Group
-# Begin Group "Header Files"
-
-# PROP Default_Filter "h;hpp;hxx;hm;inl"
-# End Group
-# Begin Group "Resource Files"
-
-# PROP Default_Filter "ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe"
-# End Group
-# Begin Group "library"
-
-# PROP Default_Filter ""
-# End Group
-# Begin Source File
-
-SOURCE=.\ReadMe.txt
-# End Source File
-# End Target
-# End Project
+# Microsoft Developer Studio Project File - Name="dumpvid" - Package Owner=<4>
+# Microsoft Developer Studio Generated Build File, Format Version 6.00
+# ** DO NOT EDIT **
+
+# TARGTYPE "Win32 (x86) Console Application" 0x0103
+
+CFG=dumpvid - Win32 Debug
+!MESSAGE This is not a valid makefile. To build this project using NMAKE,
+!MESSAGE use the Export Makefile command and run
+!MESSAGE
+!MESSAGE NMAKE /f "dumpvid.mak".
+!MESSAGE
+!MESSAGE You can specify a configuration when running NMAKE
+!MESSAGE by defining the macro CFG on the command line. For example:
+!MESSAGE
+!MESSAGE NMAKE /f "dumpvid.mak" CFG="dumpvid - Win32 Debug"
+!MESSAGE
+!MESSAGE Possible choices for configuration are:
+!MESSAGE
+!MESSAGE "dumpvid - Win32 Release" (based on "Win32 (x86) Console Application")
+!MESSAGE "dumpvid - Win32 Debug" (based on "Win32 (x86) Console Application")
+!MESSAGE
+
+# Begin Project
+# PROP AllowPerConfigDependencies 0
+# PROP Scc_ProjName ""
+# PROP Scc_LocalPath ""
+CPP=cl.exe
+RSC=rc.exe
+
+!IF "$(CFG)" == "dumpvid - Win32 Release"
+
+# PROP BASE Use_MFC 0
+# PROP BASE Use_Debug_Libraries 0
+# PROP BASE Output_Dir "Release"
+# PROP BASE Intermediate_Dir "Release"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 0
+# PROP Use_Debug_Libraries 0
+# PROP Output_Dir "Release"
+# PROP Intermediate_Dir "Release"
+# PROP Ignore_Export_Lib 0
+# PROP Target_Dir ""
+# ADD BASE CPP /nologo /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /c
+# ADD CPP /nologo /MD /W3 /GX /O2 /I "..\..\..\include" /I "..\..\..\..\ogg\include" /I "..\wincompat" /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /FD /c
+# SUBTRACT CPP /YX /Yc /Yu
+# ADD BASE RSC /l 0x409 /d "NDEBUG"
+# ADD RSC /l 0x409 /d "NDEBUG"
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /machine:I386
+# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib theora_static.lib ogg_static.lib /nologo /subsystem:console /machine:I386 /nodefaultlib:"LIBCMT" /out:"dump_vid.exe" /libpath:"..\..\Static_Release" /libpath:"..\..\..\..\ogg\win32\Static_Release" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Release" /libpath:"..\..\..\..\vorbis\win32\VorbisEnc_Static_Release"
+
+!ELSEIF "$(CFG)" == "dumpvid - Win32 Debug"
+
+# PROP BASE Use_MFC 0
+# PROP BASE Use_Debug_Libraries 1
+# PROP BASE Output_Dir "Debug"
+# PROP BASE Intermediate_Dir "Debug"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 0
+# PROP Use_Debug_Libraries 1
+# PROP Output_Dir "Debug"
+# PROP Intermediate_Dir "Debug"
+# PROP Ignore_Export_Lib 0
+# PROP Target_Dir ""
+# ADD BASE CPP /nologo /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /GZ /c
+# ADD CPP /nologo /MDd /W3 /Gm /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\..\ogg\include" /I "..\wincompat" /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /FR /FD /GZ /c
+# SUBTRACT CPP /YX /Yc /Yu
+# ADD BASE RSC /l 0x409 /d "_DEBUG"
+# ADD RSC /l 0x409 /d "_DEBUG"
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /debug /machine:I386 /pdbtype:sept
+# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib theora_static_d.lib ogg_static_d.lib /nologo /subsystem:console /debug /machine:I386 /nodefaultlib:"LIBCD" /out:"dump_vid.exe" /pdbtype:sept /libpath:"..\..\Static_Debug" /libpath:"..\..\..\..\ogg\win32\Static_Debug" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Debug" /libpath:"..\..\..\..\vorbis\win32\VorbisEnc_Static_Debug"
+# SUBTRACT LINK32 /nodefaultlib
+
+!ENDIF
+
+# Begin Target
+
+# Name "dumpvid - Win32 Release"
+# Name "dumpvid - Win32 Debug"
+# Begin Group "Source Files"
+
+# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
+# Begin Source File
+
+SOURCE=..\..\..\examples\dump_video.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\wincompat\getopt.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\wincompat\getopt_long.c
+# End Source File
+# End Group
+# Begin Group "Header Files"
+
+# PROP Default_Filter "h;hpp;hxx;hm;inl"
+# End Group
+# Begin Group "Resource Files"
+
+# PROP Default_Filter "ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe"
+# End Group
+# Begin Group "library"
+
+# PROP Default_Filter ""
+# End Group
+# Begin Source File
+
+SOURCE=.\ReadMe.txt
+# End Source File
+# End Target
+# End Project
Property changes on: branches/theora-mmx/win32/experimental/dumpvid/dumpvid.dsp
___________________________________________________________________
Name: svn:eol-style
+ CRLF
Modified: branches/theora-mmx/win32/experimental/encoderwin/encoderwin.dsp
===================================================================
--- branches/theora-mmx/win32/experimental/encoderwin/encoderwin.dsp 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/win32/experimental/encoderwin/encoderwin.dsp 2004-09-30 11:03:25 UTC (rev 7894)
@@ -1,121 +1,121 @@
-# Microsoft Developer Studio Project File - Name="encoderwin" - Package Owner=<4>
-# Microsoft Developer Studio Generated Build File, Format Version 6.00
-# ** DO NOT EDIT **
-
-# TARGTYPE "Win32 (x86) Console Application" 0x0103
-
-CFG=encoderwin - Win32 Debug
-!MESSAGE This is not a valid makefile. To build this project using NMAKE,
-!MESSAGE use the Export Makefile command and run
-!MESSAGE
-!MESSAGE NMAKE /f "encoderwin.mak".
-!MESSAGE
-!MESSAGE You can specify a configuration when running NMAKE
-!MESSAGE by defining the macro CFG on the command line. For example:
-!MESSAGE
-!MESSAGE NMAKE /f "encoderwin.mak" CFG="encoderwin - Win32 Debug"
-!MESSAGE
-!MESSAGE Possible choices for configuration are:
-!MESSAGE
-!MESSAGE "encoderwin - Win32 Release" (based on "Win32 (x86) Console Application")
-!MESSAGE "encoderwin - Win32 Debug" (based on "Win32 (x86) Console Application")
-!MESSAGE
-
-# Begin Project
-# PROP AllowPerConfigDependencies 0
-# PROP Scc_ProjName ""
-# PROP Scc_LocalPath ""
-CPP=cl.exe
-RSC=rc.exe
-
-!IF "$(CFG)" == "encoderwin - Win32 Release"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 0
-# PROP BASE Output_Dir "Release"
-# PROP BASE Intermediate_Dir "Release"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 0
-# PROP Use_Debug_Libraries 0
-# PROP Output_Dir "Release"
-# PROP Intermediate_Dir "Release"
-# PROP Ignore_Export_Lib 0
-# PROP Target_Dir ""
-# ADD BASE CPP /nologo /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /c
-# ADD CPP /nologo /MD /W3 /GX /O2 /I "..\..\..\include" /I "..\..\..\..\vorbis\include" /I "..\..\..\..\ogg\include" /I "..\wincompat" /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /FD /c
-# SUBTRACT CPP /YX /Yc /Yu
-# ADD BASE RSC /l 0x409 /d "NDEBUG"
-# ADD RSC /l 0x409 /d "NDEBUG"
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LINK32=link.exe
-# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /machine:I386
-# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib theora_static.lib ogg_static.lib vorbis_static.lib vorbisenc_static.lib /nologo /subsystem:console /machine:I386 /nodefaultlib:"LIBCMT" /out:"encoderwin.exe" /libpath:"..\..\Static_Release" /libpath:"..\..\..\..\ogg\win32\Static_Release" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Release" /libpath:"..\..\..\..\vorbis\win32\VorbisEnc_Static_Release"
-
-!ELSEIF "$(CFG)" == "encoderwin - Win32 Debug"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "Debug"
-# PROP BASE Intermediate_Dir "Debug"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 0
-# PROP Use_Debug_Libraries 1
-# PROP Output_Dir "Debug"
-# PROP Intermediate_Dir "Debug"
-# PROP Ignore_Export_Lib 0
-# PROP Target_Dir ""
-# ADD BASE CPP /nologo /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /GZ /c
-# ADD CPP /nologo /MDd /W3 /Gm /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\..\vorbis\include" /I "..\..\..\..\ogg\include" /I "..\wincompat" /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /FD /GZ /c
-# SUBTRACT CPP /YX /Yc /Yu
-# ADD BASE RSC /l 0x409 /d "_DEBUG"
-# ADD RSC /l 0x409 /d "_DEBUG"
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LINK32=link.exe
-# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /debug /machine:I386 /pdbtype:sept
-# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib theora_static_d.lib ogg_static_d.lib vorbis_static_d.lib vorbisenc_static_d.lib /nologo /subsystem:console /debug /machine:I386 /nodefaultlib:"LIBCD" /out:"encoderwin.exe" /pdbtype:sept /libpath:"..\..\Static_Debug" /libpath:"..\..\..\..\ogg\win32\Static_Debug" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Debug" /libpath:"..\..\..\..\vorbis\win32\VorbisEnc_Static_Debug"
-# SUBTRACT LINK32 /nodefaultlib
-
-!ENDIF
-
-# Begin Target
-
-# Name "encoderwin - Win32 Release"
-# Name "encoderwin - Win32 Debug"
-# Begin Group "Source Files"
-
-# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
-# Begin Source File
-
-SOURCE=..\..\..\examples\encoder_example.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\wincompat\getopt.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\wincompat\getopt_long.c
-# End Source File
-# End Group
-# Begin Group "Header Files"
-
-# PROP Default_Filter "h;hpp;hxx;hm;inl"
-# End Group
-# Begin Group "Resource Files"
-
-# PROP Default_Filter "ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe"
-# End Group
-# Begin Group "library"
-
-# PROP Default_Filter ""
-# End Group
-# Begin Source File
-
-SOURCE=.\ReadMe.txt
-# End Source File
-# End Target
-# End Project
+# Microsoft Developer Studio Project File - Name="encoderwin" - Package Owner=<4>
+# Microsoft Developer Studio Generated Build File, Format Version 6.00
+# ** DO NOT EDIT **
+
+# TARGTYPE "Win32 (x86) Console Application" 0x0103
+
+CFG=encoderwin - Win32 Debug
+!MESSAGE This is not a valid makefile. To build this project using NMAKE,
+!MESSAGE use the Export Makefile command and run
+!MESSAGE
+!MESSAGE NMAKE /f "encoderwin.mak".
+!MESSAGE
+!MESSAGE You can specify a configuration when running NMAKE
+!MESSAGE by defining the macro CFG on the command line. For example:
+!MESSAGE
+!MESSAGE NMAKE /f "encoderwin.mak" CFG="encoderwin - Win32 Debug"
+!MESSAGE
+!MESSAGE Possible choices for configuration are:
+!MESSAGE
+!MESSAGE "encoderwin - Win32 Release" (based on "Win32 (x86) Console Application")
+!MESSAGE "encoderwin - Win32 Debug" (based on "Win32 (x86) Console Application")
+!MESSAGE
+
+# Begin Project
+# PROP AllowPerConfigDependencies 0
+# PROP Scc_ProjName ""
+# PROP Scc_LocalPath ""
+CPP=cl.exe
+RSC=rc.exe
+
+!IF "$(CFG)" == "encoderwin - Win32 Release"
+
+# PROP BASE Use_MFC 0
+# PROP BASE Use_Debug_Libraries 0
+# PROP BASE Output_Dir "Release"
+# PROP BASE Intermediate_Dir "Release"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 0
+# PROP Use_Debug_Libraries 0
+# PROP Output_Dir "Release"
+# PROP Intermediate_Dir "Release"
+# PROP Ignore_Export_Lib 0
+# PROP Target_Dir ""
+# ADD BASE CPP /nologo /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /c
+# ADD CPP /nologo /MD /W3 /GX /O2 /I "..\..\..\include" /I "..\..\..\..\vorbis\include" /I "..\..\..\..\ogg\include" /I "..\wincompat" /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /FD /c
+# SUBTRACT CPP /YX /Yc /Yu
+# ADD BASE RSC /l 0x409 /d "NDEBUG"
+# ADD RSC /l 0x409 /d "NDEBUG"
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /machine:I386
+# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib theora_static.lib ogg_static.lib vorbis_static.lib vorbisenc_static.lib /nologo /subsystem:console /machine:I386 /nodefaultlib:"LIBCMT" /out:"encoderwin.exe" /libpath:"..\..\Static_Release" /libpath:"..\..\..\..\ogg\win32\Static_Release" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Release" /libpath:"..\..\..\..\vorbis\win32\VorbisEnc_Static_Release"
+
+!ELSEIF "$(CFG)" == "encoderwin - Win32 Debug"
+
+# PROP BASE Use_MFC 0
+# PROP BASE Use_Debug_Libraries 1
+# PROP BASE Output_Dir "Debug"
+# PROP BASE Intermediate_Dir "Debug"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 0
+# PROP Use_Debug_Libraries 1
+# PROP Output_Dir "Debug"
+# PROP Intermediate_Dir "Debug"
+# PROP Ignore_Export_Lib 0
+# PROP Target_Dir ""
+# ADD BASE CPP /nologo /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /GZ /c
+# ADD CPP /nologo /MDd /W3 /Gm /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\..\vorbis\include" /I "..\..\..\..\ogg\include" /I "..\wincompat" /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /FD /GZ /c
+# SUBTRACT CPP /YX /Yc /Yu
+# ADD BASE RSC /l 0x409 /d "_DEBUG"
+# ADD RSC /l 0x409 /d "_DEBUG"
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /debug /machine:I386 /pdbtype:sept
+# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib theora_static_d.lib ogg_static_d.lib vorbis_static_d.lib vorbisenc_static_d.lib /nologo /subsystem:console /debug /machine:I386 /nodefaultlib:"LIBCD" /out:"encoderwin.exe" /pdbtype:sept /libpath:"..\..\Static_Debug" /libpath:"..\..\..\..\ogg\win32\Static_Debug" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Debug" /libpath:"..\..\..\..\vorbis\win32\VorbisEnc_Static_Debug"
+# SUBTRACT LINK32 /nodefaultlib
+
+!ENDIF
+
+# Begin Target
+
+# Name "encoderwin - Win32 Release"
+# Name "encoderwin - Win32 Debug"
+# Begin Group "Source Files"
+
+# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
+# Begin Source File
+
+SOURCE=..\..\..\examples\encoder_example.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\wincompat\getopt.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\wincompat\getopt_long.c
+# End Source File
+# End Group
+# Begin Group "Header Files"
+
+# PROP Default_Filter "h;hpp;hxx;hm;inl"
+# End Group
+# Begin Group "Resource Files"
+
+# PROP Default_Filter "ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe"
+# End Group
+# Begin Group "library"
+
+# PROP Default_Filter ""
+# End Group
+# Begin Source File
+
+SOURCE=.\ReadMe.txt
+# End Source File
+# End Target
+# End Project
Property changes on: branches/theora-mmx/win32/experimental/encoderwin/encoderwin.dsp
___________________________________________________________________
Name: svn:eol-style
+ CRLF
Modified: branches/theora-mmx/win32/experimental/splayer/splayer.dsp
===================================================================
--- branches/theora-mmx/win32/experimental/splayer/splayer.dsp 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/win32/experimental/splayer/splayer.dsp 2004-09-30 11:03:25 UTC (rev 7894)
@@ -1,114 +1,114 @@
-# Microsoft Developer Studio Project File - Name="splayer" - Package Owner=<4>
-# Microsoft Developer Studio Generated Build File, Format Version 6.00
-# ** DO NOT EDIT **
-
-# TARGTYPE "Win32 (x86) Console Application" 0x0103
-
-CFG=splayer - Win32 Debug
-!MESSAGE This is not a valid makefile. To build this project using NMAKE,
-!MESSAGE use the Export Makefile command and run
-!MESSAGE
-!MESSAGE NMAKE /f "splayer.mak".
-!MESSAGE
-!MESSAGE You can specify a configuration when running NMAKE
-!MESSAGE by defining the macro CFG on the command line. For example:
-!MESSAGE
-!MESSAGE NMAKE /f "splayer.mak" CFG="splayer - Win32 Debug"
-!MESSAGE
-!MESSAGE Possible choices for configuration are:
-!MESSAGE
-!MESSAGE "splayer - Win32 Release" (based on "Win32 (x86) Console Application")
-!MESSAGE "splayer - Win32 Debug" (based on "Win32 (x86) Console Application")
-!MESSAGE
-
-# Begin Project
-# PROP AllowPerConfigDependencies 0
-# PROP Scc_ProjName ""
-# PROP Scc_LocalPath ""
-CPP=cl.exe
-RSC=rc.exe
-
-!IF "$(CFG)" == "splayer - Win32 Release"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 0
-# PROP BASE Output_Dir "Release"
-# PROP BASE Intermediate_Dir "Release"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 0
-# PROP Use_Debug_Libraries 0
-# PROP Output_Dir ""
-# PROP Intermediate_Dir "Release"
-# PROP Ignore_Export_Lib 0
-# PROP Target_Dir ""
-# ADD BASE CPP /nologo /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /c
-# ADD CPP /nologo /W3 /GX /O2 /I "..\..\..\include" /I "..\..\..\..\vorbis\include" /I "..\..\..\..\ogg\include" /I "SDL-1.2.5\include" /I "portaudio\pa_common" /I "portaudio\pablio" /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /YX /FD /c
-# ADD BASE RSC /l 0x409 /d "NDEBUG"
-# ADD RSC /l 0x409 /d "NDEBUG"
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LINK32=link.exe
-# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /machine:I386
-# ADD LINK32 MSVCRT.LIB theora_static.lib ogg_static.lib vorbis_static.lib SDL.lib SDLmain.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib winmm.lib /nologo /subsystem:console /machine:I386 /nodefaultlib /libpath:"..\..\Static_Release" /libpath:"..\..\..\..\ogg\win32\Static_Release" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Release" /libpath:"SDL-1.2.5\lib"
-
-!ELSEIF "$(CFG)" == "splayer - Win32 Debug"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "Debug"
-# PROP BASE Intermediate_Dir "Debug"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 0
-# PROP Use_Debug_Libraries 1
-# PROP Output_Dir ""
-# PROP Intermediate_Dir "Debug"
-# PROP Ignore_Export_Lib 0
-# PROP Target_Dir ""
-# ADD BASE CPP /nologo /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /GZ /c
-# ADD CPP /nologo /ML /W3 /Gm /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\..\vorbis\include" /I "..\..\..\..\ogg\include" /I "SDL-1.2.5\include" /I "portaudio\pa_common" /I "portaudio\pablio" /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /FR /YX /FD /GZ /c
-# ADD BASE RSC /l 0x409 /d "_DEBUG"
-# ADD RSC /l 0x409 /d "_DEBUG"
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LINK32=link.exe
-# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /debug /machine:I386 /pdbtype:sept
-# ADD LINK32 MSVCRT.lib theora_static_d.lib ogg_static_d.lib vorbis_static_d.lib SDL.lib SDLmain.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib winmm.lib /nologo /subsystem:console /debug /machine:I386 /nodefaultlib /pdbtype:sept /libpath:"..\..\Static_Debug" /libpath:"..\..\..\..\ogg\win32\Static_Debug" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Debug" /libpath:"SDL-1.2.5\lib"
-
-!ENDIF
-
-# Begin Target
-
-# Name "splayer - Win32 Release"
-# Name "splayer - Win32 Debug"
-# Begin Group "Source Files"
-
-# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
-# Begin Source File
-
-SOURCE=.\portaudio\pa_common\pa_lib.c
-# End Source File
-# Begin Source File
-
-SOURCE=.\portaudio\pa_win_wmme\pa_win_wmme.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\..\..\examples\splayer.c
-# End Source File
-# End Group
-# Begin Group "Header Files"
-
-# PROP Default_Filter "h;hpp;hxx;hm;inl"
-# End Group
-# Begin Group "Resource Files"
-
-# PROP Default_Filter "ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe"
-# End Group
-# Begin Source File
-
-SOURCE=.\ReadMe.txt
-# End Source File
-# End Target
-# End Project
+# Microsoft Developer Studio Project File - Name="splayer" - Package Owner=<4>
+# Microsoft Developer Studio Generated Build File, Format Version 6.00
+# ** DO NOT EDIT **
+
+# TARGTYPE "Win32 (x86) Console Application" 0x0103
+
+CFG=splayer - Win32 Debug
+!MESSAGE This is not a valid makefile. To build this project using NMAKE,
+!MESSAGE use the Export Makefile command and run
+!MESSAGE
+!MESSAGE NMAKE /f "splayer.mak".
+!MESSAGE
+!MESSAGE You can specify a configuration when running NMAKE
+!MESSAGE by defining the macro CFG on the command line. For example:
+!MESSAGE
+!MESSAGE NMAKE /f "splayer.mak" CFG="splayer - Win32 Debug"
+!MESSAGE
+!MESSAGE Possible choices for configuration are:
+!MESSAGE
+!MESSAGE "splayer - Win32 Release" (based on "Win32 (x86) Console Application")
+!MESSAGE "splayer - Win32 Debug" (based on "Win32 (x86) Console Application")
+!MESSAGE
+
+# Begin Project
+# PROP AllowPerConfigDependencies 0
+# PROP Scc_ProjName ""
+# PROP Scc_LocalPath ""
+CPP=cl.exe
+RSC=rc.exe
+
+!IF "$(CFG)" == "splayer - Win32 Release"
+
+# PROP BASE Use_MFC 0
+# PROP BASE Use_Debug_Libraries 0
+# PROP BASE Output_Dir "Release"
+# PROP BASE Intermediate_Dir "Release"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 0
+# PROP Use_Debug_Libraries 0
+# PROP Output_Dir ""
+# PROP Intermediate_Dir "Release"
+# PROP Ignore_Export_Lib 0
+# PROP Target_Dir ""
+# ADD BASE CPP /nologo /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /c
+# ADD CPP /nologo /W3 /GX /O2 /I "..\..\..\include" /I "..\..\..\..\vorbis\include" /I "..\..\..\..\ogg\include" /I "SDL-1.2.5\include" /I "portaudio\pa_common" /I "portaudio\pablio" /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /YX /FD /c
+# ADD BASE RSC /l 0x409 /d "NDEBUG"
+# ADD RSC /l 0x409 /d "NDEBUG"
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /machine:I386
+# ADD LINK32 MSVCRT.LIB theora_static.lib ogg_static.lib vorbis_static.lib SDL.lib SDLmain.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib winmm.lib /nologo /subsystem:console /machine:I386 /nodefaultlib /libpath:"..\..\Static_Release" /libpath:"..\..\..\..\ogg\win32\Static_Release" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Release" /libpath:"SDL-1.2.5\lib"
+
+!ELSEIF "$(CFG)" == "splayer - Win32 Debug"
+
+# PROP BASE Use_MFC 0
+# PROP BASE Use_Debug_Libraries 1
+# PROP BASE Output_Dir "Debug"
+# PROP BASE Intermediate_Dir "Debug"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 0
+# PROP Use_Debug_Libraries 1
+# PROP Output_Dir ""
+# PROP Intermediate_Dir "Debug"
+# PROP Ignore_Export_Lib 0
+# PROP Target_Dir ""
+# ADD BASE CPP /nologo /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /GZ /c
+# ADD CPP /nologo /ML /W3 /Gm /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\..\vorbis\include" /I "..\..\..\..\ogg\include" /I "SDL-1.2.5\include" /I "portaudio\pa_common" /I "portaudio\pablio" /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /FR /YX /FD /GZ /c
+# ADD BASE RSC /l 0x409 /d "_DEBUG"
+# ADD RSC /l 0x409 /d "_DEBUG"
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /debug /machine:I386 /pdbtype:sept
+# ADD LINK32 MSVCRT.lib theora_static_d.lib ogg_static_d.lib vorbis_static_d.lib SDL.lib SDLmain.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib winmm.lib /nologo /subsystem:console /debug /machine:I386 /nodefaultlib /pdbtype:sept /libpath:"..\..\Static_Debug" /libpath:"..\..\..\..\ogg\win32\Static_Debug" /libpath:"..\..\..\..\vorbis\win32\Vorbis_Static_Debug" /libpath:"SDL-1.2.5\lib"
+
+!ENDIF
+
+# Begin Target
+
+# Name "splayer - Win32 Release"
+# Name "splayer - Win32 Debug"
+# Begin Group "Source Files"
+
+# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
+# Begin Source File
+
+SOURCE=.\portaudio\pa_common\pa_lib.c
+# End Source File
+# Begin Source File
+
+SOURCE=.\portaudio\pa_win_wmme\pa_win_wmme.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\..\..\examples\splayer.c
+# End Source File
+# End Group
+# Begin Group "Header Files"
+
+# PROP Default_Filter "h;hpp;hxx;hm;inl"
+# End Group
+# Begin Group "Resource Files"
+
+# PROP Default_Filter "ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe"
+# End Group
+# Begin Source File
+
+SOURCE=.\ReadMe.txt
+# End Source File
+# End Target
+# End Project
Property changes on: branches/theora-mmx/win32/experimental/splayer/splayer.dsp
___________________________________________________________________
Name: svn:eol-style
+ CRLF
Property changes on: branches/theora-mmx/win32/experimental/transcoder/transcoder.dsp
___________________________________________________________________
Name: svn:eol-style
+ CRLF
Modified: branches/theora-mmx/win32/theora_static.dsp
===================================================================
--- branches/theora-mmx/win32/theora_static.dsp 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/win32/theora_static.dsp 2004-09-30 11:03:25 UTC (rev 7894)
@@ -1,212 +1,212 @@
-# Microsoft Developer Studio Project File - Name="theora_static" - Package Owner=<4>
-# Microsoft Developer Studio Generated Build File, Format Version 6.00
-# ** DO NOT EDIT **
-
-# TARGTYPE "Win32 (x86) Static Library" 0x0104
-
-CFG=theora_static - Win32 Debug
-!MESSAGE This is not a valid makefile. To build this project using NMAKE,
-!MESSAGE use the Export Makefile command and run
-!MESSAGE
-!MESSAGE NMAKE /f "theora_static.mak".
-!MESSAGE
-!MESSAGE You can specify a configuration when running NMAKE
-!MESSAGE by defining the macro CFG on the command line. For example:
-!MESSAGE
-!MESSAGE NMAKE /f "theora_static.mak" CFG="theora_static - Win32 Debug"
-!MESSAGE
-!MESSAGE Possible choices for configuration are:
-!MESSAGE
-!MESSAGE "theora_static - Win32 Release" (based on "Win32 (x86) Static Library")
-!MESSAGE "theora_static - Win32 Debug" (based on "Win32 (x86) Static Library")
-!MESSAGE
-
-# Begin Project
-# PROP AllowPerConfigDependencies 0
-# PROP Scc_ProjName ""
-# PROP Scc_LocalPath ""
-CPP=cl.exe
-RSC=rc.exe
-
-!IF "$(CFG)" == "theora_static - Win32 Release"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 0
-# PROP BASE Output_Dir "Release"
-# PROP BASE Intermediate_Dir "Release"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 0
-# PROP Use_Debug_Libraries 0
-# PROP Output_Dir "Static_Release"
-# PROP Intermediate_Dir "Static_Release"
-# PROP Target_Dir ""
-# ADD BASE CPP /nologo /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_MBCS" /D "_LIB" /YX /FD /c
-# ADD CPP /nologo /MT /W3 /GX /O2 /I "..\..\ogg\include" /I "..\..\theora\include" /D "WIN32" /D "NDEBUG" /D "_MBCS" /D "_LIB" /YX /FD /c
-# ADD BASE RSC /l 0x409 /d "NDEBUG"
-# ADD RSC /l 0x409 /d "NDEBUG"
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LIB32=link.exe -lib
-# ADD BASE LIB32 /nologo
-# ADD LIB32 /nologo
-
-!ELSEIF "$(CFG)" == "theora_static - Win32 Debug"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "Debug"
-# PROP BASE Intermediate_Dir "Debug"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 0
-# PROP Use_Debug_Libraries 1
-# PROP Output_Dir "Static_Debug"
-# PROP Intermediate_Dir "Static_Debug"
-# PROP Target_Dir ""
-# ADD BASE CPP /nologo /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_MBCS" /D "_LIB" /YX /FD /GZ /c
-# ADD CPP /nologo /W3 /Gm /GX /ZI /Od /I "..\..\ogg\include" /I "..\..\theora\include" /D "WIN32" /D "_DEBUG" /D "_MBCS" /D "_LIB" /YX /FD /GZ /c
-# ADD BASE RSC /l 0x409 /d "_DEBUG"
-# ADD RSC /l 0x409 /d "_DEBUG"
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LIB32=link.exe -lib
-# ADD BASE LIB32 /nologo
-# ADD LIB32 /nologo /out:"Static_Debug\theora_static_d.lib"
-
-!ENDIF
-
-# Begin Target
-
-# Name "theora_static - Win32 Release"
-# Name "theora_static - Win32 Debug"
-# Begin Group "Source Files"
-
-# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
-# Begin Source File
-
-SOURCE=..\lib\blockmap.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\comment.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\dct.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\dct_decode.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\dct_encode.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\decode.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\encode.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\frarray.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\frinit.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\huffman.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\idct.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\mcomp.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\misc_common.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\pb.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\pp.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\quant.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\reconstruct.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\scan.c
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\toplevel.c
-# End Source File
-# End Group
-# Begin Group "Header Files"
-
-# PROP Default_Filter "h;hpp;hxx;hm;inl"
-# Begin Source File
-
-SOURCE=..\lib\block_inline.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\encoder_internal.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\encoder_lookup.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\huffman.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\hufftables.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\mcomp.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\ogg\ogg.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\ogg\os_types.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\pp.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\quant_lookup.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\lib\toplevel_lookup.h
-# End Source File
-# End Group
-# End Target
-# End Project
+# Microsoft Developer Studio Project File - Name="theora_static" - Package Owner=<4>
+# Microsoft Developer Studio Generated Build File, Format Version 6.00
+# ** DO NOT EDIT **
+
+# TARGTYPE "Win32 (x86) Static Library" 0x0104
+
+CFG=theora_static - Win32 Debug
+!MESSAGE This is not a valid makefile. To build this project using NMAKE,
+!MESSAGE use the Export Makefile command and run
+!MESSAGE
+!MESSAGE NMAKE /f "theora_static.mak".
+!MESSAGE
+!MESSAGE You can specify a configuration when running NMAKE
+!MESSAGE by defining the macro CFG on the command line. For example:
+!MESSAGE
+!MESSAGE NMAKE /f "theora_static.mak" CFG="theora_static - Win32 Debug"
+!MESSAGE
+!MESSAGE Possible choices for configuration are:
+!MESSAGE
+!MESSAGE "theora_static - Win32 Release" (based on "Win32 (x86) Static Library")
+!MESSAGE "theora_static - Win32 Debug" (based on "Win32 (x86) Static Library")
+!MESSAGE
+
+# Begin Project
+# PROP AllowPerConfigDependencies 0
+# PROP Scc_ProjName ""
+# PROP Scc_LocalPath ""
+CPP=cl.exe
+RSC=rc.exe
+
+!IF "$(CFG)" == "theora_static - Win32 Release"
+
+# PROP BASE Use_MFC 0
+# PROP BASE Use_Debug_Libraries 0
+# PROP BASE Output_Dir "Release"
+# PROP BASE Intermediate_Dir "Release"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 0
+# PROP Use_Debug_Libraries 0
+# PROP Output_Dir "Static_Release"
+# PROP Intermediate_Dir "Static_Release"
+# PROP Target_Dir ""
+# ADD BASE CPP /nologo /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_MBCS" /D "_LIB" /YX /FD /c
+# ADD CPP /nologo /MT /W3 /GX /O2 /I "..\..\ogg\include" /I "..\..\theora\include" /D "WIN32" /D "NDEBUG" /D "_MBCS" /D "_LIB" /YX /FD /c
+# ADD BASE RSC /l 0x409 /d "NDEBUG"
+# ADD RSC /l 0x409 /d "NDEBUG"
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LIB32=link.exe -lib
+# ADD BASE LIB32 /nologo
+# ADD LIB32 /nologo
+
+!ELSEIF "$(CFG)" == "theora_static - Win32 Debug"
+
+# PROP BASE Use_MFC 0
+# PROP BASE Use_Debug_Libraries 1
+# PROP BASE Output_Dir "Debug"
+# PROP BASE Intermediate_Dir "Debug"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 0
+# PROP Use_Debug_Libraries 1
+# PROP Output_Dir "Static_Debug"
+# PROP Intermediate_Dir "Static_Debug"
+# PROP Target_Dir ""
+# ADD BASE CPP /nologo /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_MBCS" /D "_LIB" /YX /FD /GZ /c
+# ADD CPP /nologo /W3 /Gm /GX /ZI /Od /I "..\..\ogg\include" /I "..\..\theora\include" /D "WIN32" /D "_DEBUG" /D "_MBCS" /D "_LIB" /YX /FD /GZ /c
+# ADD BASE RSC /l 0x409 /d "_DEBUG"
+# ADD RSC /l 0x409 /d "_DEBUG"
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LIB32=link.exe -lib
+# ADD BASE LIB32 /nologo
+# ADD LIB32 /nologo /out:"Static_Debug\theora_static_d.lib"
+
+!ENDIF
+
+# Begin Target
+
+# Name "theora_static - Win32 Release"
+# Name "theora_static - Win32 Debug"
+# Begin Group "Source Files"
+
+# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
+# Begin Source File
+
+SOURCE=..\lib\blockmap.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\comment.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\dct.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\dct_decode.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\dct_encode.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\decode.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\encode.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\frarray.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\frinit.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\huffman.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\idct.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\mcomp.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\misc_common.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\pb.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\pp.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\quant.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\reconstruct.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\scan.c
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\toplevel.c
+# End Source File
+# End Group
+# Begin Group "Header Files"
+
+# PROP Default_Filter "h;hpp;hxx;hm;inl"
+# Begin Source File
+
+SOURCE=..\lib\block_inline.h
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\encoder_internal.h
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\encoder_lookup.h
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\huffman.h
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\hufftables.h
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\mcomp.h
+# End Source File
+# Begin Source File
+
+SOURCE=..\ogg\ogg.h
+# End Source File
+# Begin Source File
+
+SOURCE=..\ogg\os_types.h
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\pp.h
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\quant_lookup.h
+# End Source File
+# Begin Source File
+
+SOURCE=..\lib\toplevel_lookup.h
+# End Source File
+# End Group
+# End Target
+# End Project
Property changes on: branches/theora-mmx/win32/theora_static.dsp
___________________________________________________________________
Name: svn:eol-style
+ CRLF
More information about the commits
mailing list
--- branches/theora-mmx/examples/dump_video.c 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/examples/dump_video.c 2004-09-30 11:03:25 UTC (rev 7894)
@@ -5,7 +5,7 @@
* GOVERNED BY A BSD-STYLE SOURCE LICENSE INCLUDED WITH THIS SOURCE *
* IN 'COPYING'. PLEASE READ THESE TERMS BEFORE DISTRIBUTING. *
* *
- * THE Theora SOURCE CODE IS COPYRIGHT (C) 2002-2003 *
+ * THE Theora SOURCE CODE IS COPYRIGHT (C) 2002-2004 *
* by the Xiph.Org Foundation http://www.xiph.org/ *
* *
********************************************************************
@@ -31,16 +31,17 @@
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
-/*#include <sys/time.h>*/
#include <sys/types.h>
#include <sys/stat.h>
-/*Yes, yes, we're going to hell.*/
+
#if defined(_WIN32)
#include <io.h>
#endif
+
#include <fcntl.h>
#include <math.h>
#include <signal.h>
+
#include "getopt.h"
#include "theora/theora.h"
@@ -86,10 +87,13 @@
got_sigint = 1;
}
+/* this is a nop in the current implementation. we could
+ open a file here or something if so moved. */
static void open_video(void){
-
+ return;
}
+/* write out the planar YUV frame, uncropped */
static void video_write(void){
int i;
@@ -104,7 +108,7 @@
fwrite(yuv.v+yuv.uv_stride*i, 1, yuv.uv_width, outfile);
}
-/* dump the theora (or vorbis) comment header */
+/* dump the theora comment header */
static int dump_comments(theora_comment *tc){
int i, len;
char *value;
@@ -127,9 +131,7 @@
return(0);
}
-/* helper: push a page into the appropriate steam */
-/* this can be done blindly; a stream won't accept a page
- that doesn't belong to it */
+/* helper: push a page into the steam for packetization */
static int queue_page(ogg_page *page){
if(theora_p)ogg_stream_pagein(&to,&og);
return 0;
@@ -154,7 +156,7 @@
outfile = stdout;
-#ifdef _WIN32 /* We need to set stdin/stdout to binary mode. Damn windows. */
+#ifdef _WIN32 /* We need to set stdin/stdout to binary mode on windows. */
/* Beware the evil ifdef. We avoid these where we can, but this one we
cannot. Don't add any more, you'll probably go to hell if you do. */
_setmode( _fileno( stdin ), _O_BINARY );
@@ -188,19 +190,34 @@
}
}
+
+ /*
+ Ok, Ogg parsing. The idea here is we have a bitstream
+ that is made up of Ogg pages. The libogg sync layer will
+ find them for us. There may be pages from several logical
+ streams interleaved; we find the first theora stream and
+ ignore any others.
+
+ Then we pass the pages for our stream to the libogg stream
+ layer which assembles our original set of packets out of
+ them. It's the packets that libtheora actually knows how
+ to handle.
+ */
+
/* start up Ogg stream synchronization layer */
ogg_sync_init(&oy);
- /* init supporting Vorbis structures needed in header parsing */
- /*vorbis_info_init(&vi);*/
- /*vorbis_comment_init(&vc);*/
-
/* init supporting Theora structures needed in header parsing */
theora_comment_init(&tc);
theora_info_init(&ti);
/* Ogg file open; parse the headers */
- /* Only interested in Vorbis/Theora streams */
+
+ /* Vorbis and Theora both depend on some initial header packets
+ for decoder setup and initialization. We retrieve these first
+ before entering the main decode loop. */
+
+ /* Only interested in Theora streams */
while(!stateflag){
int ret=buffer_data(infile,&oy);
if(ret==0)break;
@@ -221,7 +238,7 @@
/* identify the codec: try theora */
if(!theora_p && theora_decode_header(&ti,&tc,&op)>=0){
- /* it is theora */
+ /* it is theora -- save this stream state */
memcpy(&to,&test,sizeof(test));
theora_p=1;
}else{
@@ -229,7 +246,7 @@
ogg_stream_clear(&test);
}
}
- /* fall through to non-bos page parsing */
+ /* fall through to non-initial page parsing */
}
/* we're expecting more header packets. */
@@ -255,9 +272,9 @@
care about, or the stream is not obeying spec */
if(ogg_sync_pageout(&oy,&og)>0){
- queue_page(&og); /* demux into the appropriate stream */
+ queue_page(&og); /* demux into the stream state */
}else{
- int ret=buffer_data(infile,&oy); /* someone needs more data */
+ int ret=buffer_data(infile,&oy); /* need more data */
if(ret==0){
fprintf(stderr,"End of file while searching for codec headers.\n");
exit(1);
@@ -265,7 +282,7 @@
}
}
- /* and now we have it all. initialize decoders */
+ /* Now we have all the required headers. initialize the decoder. */
if(theora_p){
theora_decode_init(&td,&ti);
fprintf(stderr,"Ogg logical stream %x is Theora %dx%d %.02f fps video\nEncoded frame content is %dx%d with %dx%d offset\n",
@@ -283,8 +300,27 @@
/* install signal handler */
signal (SIGINT, sigint_handler);
- /* on to the main decode loop.*/
+ /* Finally the main decode loop.
+ It's one Theora packet per frame, so this is pretty
+ straightforward if we're not trying to maintain sync
+ with other multiplexed streams.
+
+ the videobuf_ready flag is used to maintain the input
+ buffer in the libogg stream state. If there's no output
+ frame available at the end of the decode step, we must
+ need more input data. We could simplify this by just
+ using the return code on ogg_page_packetout(), but the
+ flag system extends easily to the case were you care
+ about more than one multiplexed stream (like with audio
+ playback). In that case, just maintain a flag for each
+ decoder you care about, and pull data when any one of
+ them stalls.
+
+ videobuf_time holds the presentation time of the currently
+ buffered video frame. We ignore this value.
+ */
+
stateflag=0; /* playback has not begun */
/* queue any remaining pages from data we buffered but that did not
contain headers */
@@ -306,9 +342,9 @@
break;
}
- if(!videobuf_ready && feof(infile))break;
+ if(!videobuf_ready && feof(infile))break;
- if(!videobuf_ready ){
+ if(!videobuf_ready){
/* no data yet for somebody. Grab another page */
int ret=buffer_data(infile,&oy);
while(ogg_sync_pageout(&oy,&og)>0){
@@ -321,7 +357,7 @@
videobuf_ready=0;
}
- /* close everything */
+ /* end of decoder loop -- close everything */
if(theora_p){
ogg_stream_clear(&to);
Modified: branches/theora-mmx/include/theora/theora.h
===================================================================
--- branches/theora-mmx/include/theora/theora.h 2004-09-29 23:39:19 UTC (rev 7893)
+++ branches/theora-mmx/include/theora/theora.h 2004-09-30 11:03:25 UTC (rev 7894)
@@ -47,19 +47,27 @@
*/
/**
- * A YUV buffer.
+ * A YUV buffer for passing uncompressed frames to and from the codec.
+ * This holds a Y'CbCr frame in planar format. The CbCr planes can be
+ * subsampled and have their own separate dimensions and row stride
+ * offsets. Note that the strides may be negative in some
+ * configurations. For theora the width and height of the largest plane
+ * must be a multiple of 16. The actual meaningful picture size and
+ * offset are stored in the theora_info structure; frames returned by
+ * the decoder my been to be cropped for display.
+ * All samples are 8 bits.
*/
typedef struct {
- int y_width;
- int y_height;
- int y_stride;
+ int y_width; /* width of the Y' luminance plane */
+ int y_height; /* height of the luminance plane */
+ int y_stride; /* offset in bytes between successive rows */
- int uv_width;
- int uv_height;
- int uv_stride;
- unsigned char *y;
- unsigned char *u;
- unsigned char *v;
+ int uv_width; /* height of the Cb and Cr chroma planes */
+ int uv_height; /* width of the chroma planes */
+ int uv_stride; /* offset between successive chroma rows */
+ unsigned char *y; /* pointer to start of luminance data */
+ unsigned char *u; /* pointer to start of Cb data */
+ unsigned char *v; /* pointer to start of Cr data */
} yuv_buffer;
@@ -67,11 +75,16 @@
* A Colorspace.
*/
typedef enum {
- OC_CS_UNSPECIFIED,
- OC_CS_ITU_REC_470M,
- OC_CS_ITU_REC_470BG,
+ OC_CS_UNSPECIFIED, /**< the colorspace is unknown or unspecified */
+ OC_CS_ITU_REC_470M, /**< best option for 'NTSC' content */
+ OC_CS_ITU_REC_470BG, /**< best option for 'PAL' content */
} theora_colorspace;
+/**
+ * Theora bitstream info.
+ * Contains the basic playback parameters for a stream,
+ * corresponds to the initial 'info' header packet.
+ */
typedef struct {
ogg_uint32_t width;
ogg_uint32_t height;
@@ -86,7 +99,7 @@
theora_colorspace colorspace;
int target_bitrate;
int quality;
- int quick_p; /** <= quick encode/decode */
+ int quick_p; /**< quick encode/decode */
/* decode only */
unsigned char version_major;
@@ -109,6 +122,8 @@
} theora_info;
+/** Codec internal state and context.
+ */
typedef struct{
theora_info *i;
ogg_int64_t granulepos;
@@ -118,11 +133,30 @@
} theora_state;
+/**
+ * Comment header metadata.
+ *
+ * This structure holds the in-stream metadata corresponding to
+ * the 'comment' header packet.
+ *
+ * Meta data is stored as a series of (tag, value) pairs, in
+ * length-encoded string vectors. The first occurence of the
+ * '=' character delimits the tag and value. A particular tag
+ * may occur more than once. The character set encoding for
+ * the strings is always utf-8, but the tag names are limited
+ * to case-insensitive ascii. See the spec for details.
+ *
+ * In filling in this structure, theora_decode_header() will
+ * null-terminate the user_comment strings for safety. However,
+ * the bitstream format itself treats them as 8-bit clean,
+ * and so the length array should be treated as authoritative
+ * for their length.
+ */
typedef struct theora_comment{
- char **user_comments;
- int *comment_lengths;
- int comments;
- char *vendor;
+ char **user_comments; /**< an array of comment string vectors */
+ int *comment_lengths; /**< an array of corresponding string vector lengths in bytes */
+ int comments; /**< the total number of comment string vectors */
+ char *vendor; /**< the vendor string identifying the encoder, null terminated */
} theora_comment;
@@ -136,8 +170,8 @@
#define OC_BADPACKET -24
#define OC_NEWPACKET -25
/**
* Retrieve a human-readable string to identify the vendor and version.
* \returns a version string.
*/
extern const char *theora_version_string(void);
@@ -162,7 +196,7 @@
extern int theora_encode_init(theora_state *th, theora_info *c);
/**
- * Input a YUV buffer into the theora encoder.
+ * Submit a YUV buffer to the theora encoder.
* \param t A theora_state handle previously initialized for encoding.
* \param yuv A buffer of YUV data to encode.
* \retval OC_EINVAL Encoder is not ready, or is finished.
@@ -172,10 +206,10 @@
extern int theora_encode_YUVin(theora_state *t, yuv_buffer *yuv);
/**
- * Request the next packet of encoded video. The encoded data is placed
- * in a user-provided ogg_packet structure.
+ * Request the next packet of encoded video.
+ * The encoded data is placed in a user-provided ogg_packet structure.
* \param t A theora_state handle previously initialized for encoding.
- * \param last_p ???
+ * \param last_p whether this is the last packet the encoder should produce.
* \param op An ogg_packet structure to fill. libtheora will set all
* elements of this structure, including a pointer to encoded
* data. The memory for the encoded data is owned by libtheora.
@@ -304,6 +338,26 @@
extern double theora_granule_time(theora_state *th,ogg_int64_t granulepos);
/**
+ * Report whether a theora packet is a header or not
+ * This function does no verification beyond checking the header
+ * flag bit so it should not be used for bitstream identification;
+ * use theora_decode_header() for that.
+ * \param op An ogg_packet containing encoded theora data.
+ * \retval 1 The packet is a header packet
+ * \retval 0 The packet is not a header packet (and so contains frame data)
+ */
+extern int theora_packet_isheader(ogg_packet *op);
+
+/**
+ * Report whether a theora packet is a keyframe or not
+ * \param op An ogg_packet containing encoded theora data.
+ * \retval 1 The packet contains a keyframe image
+ * \retval 0 The packet is contains an interframe delta
+ * \retval -1 the packet is not an image data packet at all
+ */
+extern int theora_packet_iskeyframe(ogg_packet *op);
+
+/**
* Convert a granulepos to an absolute frame number. The granulepos is
* interpreted in the context of a given theora_state handle.
* \param th A previously initialized theora_state handle (encode or decode)
@@ -136,8 +170,8 @@
#define OC_BADPACKET -24
#define OC_NEWPACKET -25
-/**
- * Retrieve a human-readable string to identify the vendor and version.
+/**
+ * Retrieve a human-readable string to identify the encoder vendor and version.
* \returns a version string.
*/
Modified: branches/theora-mmx/lib/Makefile.am
===================================================================